@@ -1,4 +1,5 @@
-yaml = '''---
+yaml = '''
+---
 apiVersion: v1
 kind: PersistentVolumeClaim
 metadata:
@@ -31,4 +32,5 @@ spec:
   storageClassName: local-storage
   selector:
     matchLabels:
-      app: "grafana"'''
+      app: "grafana"
+'''
